import uvicorn
from open_medicine.graphrag.config import get_settings


def main() -> None:
    settings = get_settings()
    uvicorn.run(
        "open_medicine.graphrag.server.app:app",
        host="0.0.0.0",
        port=settings.port,
        reload=False,
    )


if __name__ == "__main__":
    main()
